# SimLUCA_Blade
Xiaoyu's Package of SynLUCA Simulator enabling users to: 
    1. Define reaction system using user-friendly reaction language. 
    2. Run simulation effectively with automatically generated RHS and Jacobian matrix. 
    3. Visualize Simulation results with animations.

